@@ -126,7 +126,7 @@ function(xi = 0.2, a = 4.0, n = 1000)
     if((xi < 0) || (xi > 1)) stop("xi is not in [0,1]")
     if((a < 0) || (a > 4)) stop("a is not in [0,4]")
     x <- double(n)
-    res <- .C(R_quad_map,
+    res <- .C(tseries_quad_map,
               x = as.vector(x),
               as.double(xi),
               as.double(a),
@@ -272,7 +272,7 @@ function(x, y, colx = "black", coly = "red", typex = "l",
 boot.sample <-
 function(x, b, type)
 {
-    return(.C(R_boot,
+    return(.C(tseries_boot,
               as.vector(x, mode = "double"),
               x = as.vector(x, mode = "double"),
               as.integer(length(x)),
